@@ -37,8 +37,8 @@ from . import sandbox
 # External library imports
 from .exceptions import CyError
 from .py4cytoscape_utils import *
-from .py4cytoscape_logger import cy_log
-from .py4cytoscape_tuning import CATCHUP_FILTER_SECS, MODEL_PROPAGATION_SECS
+from .py4cytoscape_logger import cy_log, show_error
+from .py4cytoscape_tuning import CATCHUP_FILTER_SECS
 from .py4cytoscape_sandbox import get_abs_sandbox_path
 from .py4cytoscape_notebook import running_remote
 
@@ -85,7 +85,7 @@ def apply_filter(filter_name='Default filter', hide=False, network=None, base_ur
 
 @cy_log
 def create_column_filter(filter_name, column, criterion, predicate, caseSensitive=False, anyMatch=True, type='nodes',
-                         hide=False, network=None, base_url=DEFAULT_BASE_URL):
+                         hide=False, network=None, base_url=DEFAULT_BASE_URL, *, apply=True):
     """Create Column Filter.
 
     Create a filter to control node or edge selection. Works on columns of boolean, string, numeric
@@ -113,12 +113,13 @@ def create_column_filter(filter_name, column, criterion, predicate, caseSensitiv
         base_url (str): Ignore unless you need to specify a custom domain,
             port or version to connect to the CyREST API. Default is http://localhost:1234
             and the latest version of the CyREST API supported by this version of py4cytoscape.
+        apply (bool): True to execute filter immediately; False to define filter but not execute it
 
     Returns:
-        dict: {'nodes': <node list>, 'edges': <edge list>} returns list of nodes and edges selected after filter executes
+        dict: {'nodes': <node list>, 'edges': <edge list>} returns list of nodes and edges selected after filter executes; None if filter wasn't applied
 
     Raises:
-        CyError: if column doesn't exist in the table named by ``type``
+        CyError: if column doesn't exist in the table named by ``type`` or filter couldn't be applied
         requests.exceptions.RequestException: if can't connect to Cytoscape or Cytoscape returns an error
 
     Examples:
@@ -136,13 +137,17 @@ def create_column_filter(filter_name, column, criterion, predicate, caseSensitiv
         {'nodes': ['YDR395W', 'YLR362W', 'YPL248C', 'YGL035C'], 'edges': None}
         >>> create_column_filter('myFilter', 'Betweenness', [300, 600] , "BETWEEN", type='edges') # Filter edges
         {'nodes': None, 'edges': [{'YPR119W (pd) YMR043W', 'YDR412W (pp) YPR119W'}]}
+        >>> create_column_filter('myFilter', 'Betweenness', [300, 600] , "BETWEEN", type='edges', apply=False) # Define filter
+        {'nodes': None, 'edges': [{'YPR119W (pd) YMR043W', 'YDR412W (pp) YPR119W'}]}
     """
     networks.set_current_network(network, base_url=base_url)
 
     if column not in tables.get_table_column_names(type[:4], base_url=base_url):
         raise CyError('Column "%s" does not exist in the "%s" table' % (column, type[:4]))
 
-    if predicate in ['BETWEEN', 'IS_NOT_BETWEEN']:
+    if predicate == "REGEX" and check_supported_versions(cytoscape='3.9'):
+        show_error('Warning -- Cytoscape version pre-3.9 in use ... REGEX filter may hang forever')
+    elif predicate in ['BETWEEN', 'IS_NOT_BETWEEN']:
         if not isinstance(criterion, list) or len(criterion) != 2:
             raise CyError('Criterion "{criterion}" must be a list of two numeric values, e.g., [0.5, 2.0]')
     elif predicate in ['GREATER_THAN', 'GREATER_THAN_OR_EQUAL']:
@@ -173,12 +178,12 @@ def create_column_filter(filter_name, column, criterion, predicate, caseSensitiv
                 'parameters': {'criterion': criterion, 'columnName': column, 'predicate': predicate,
                                'caseSensitive': caseSensitive, 'anyMatch': anyMatch, 'type': type}}
     cmd_body = {'name': filter_name, 'json': json.dumps(cmd_json)}
-    return _create_filter_and_finish('commands/filter/create', cmd_body, hide, network, base_url)
+    return _create_filter_and_finish('commands/filter/create', cmd_body, hide, apply, network, base_url)
 
 
 @cy_log
 def create_degree_filter(filter_name, criterion, predicate='BETWEEN', edge_type='ANY', hide=False, network=None,
-                         base_url=DEFAULT_BASE_URL):
+                         base_url=DEFAULT_BASE_URL, *, apply=True):
     """Create Degree Filter.
 
     Creates a filter to control node selection base on in/out degree.
@@ -194,12 +199,13 @@ def create_degree_filter(filter_name, criterion, predicate='BETWEEN', edge_type=
         base_url (str): Ignore unless you need to specify a custom domain,
             port or version to connect to the CyREST API. Default is http://localhost:1234
             and the latest version of the CyREST API supported by this version of py4cytoscape.
+        apply (bool): True to execute filter immediately; False to define filter but not execute it
 
     Returns:
-        dict: {'nodes': <node list>, 'edges': <edge list>} returns list of nodes and edges selected after filter executes
+        dict: {'nodes': <node list>, 'edges': <edge list>} returns list of nodes and edges selected after filter executes; None if filter wasn't applied
 
     Raises:
-        CyError: if criterion is not list of two values
+        CyError: if criterion is not list of two values or filter couldn't be applied
         requests.exceptions.RequestException: if can't connect to Cytoscape or Cytoscape returns an error
 
     Examples:
@@ -211,6 +217,8 @@ def create_degree_filter(filter_name, criterion, predicate='BETWEEN', edge_type=
         {'nodes': ['YDR395W', 'YLR362W', 'YPL248C', 'YGL035C'], 'edges': None}
         >>> create_column_filter('myFilter', [2, 5], hide=True) # filter for between 2 and 5 edges, and hide them
         {'nodes': ['YDR395W', 'YLR362W', 'YPL248C', 'YGL035C'], 'edges': None}
+        >>> create_column_filter('myFilter', [2, 5], apply=False) # define filter for between 2 and 5 edges, and hide them
+        {'nodes': ['YDR395W', 'YLR362W', 'YPL248C', 'YGL035C'], 'edges': None}
     """
     networks.set_current_network(network, base_url=base_url)
 
@@ -220,11 +228,11 @@ def create_degree_filter(filter_name, criterion, predicate='BETWEEN', edge_type=
     cmd_json = {'id': 'DegreeFilter',
                 'parameters': {'criterion': criterion, 'predicate': predicate, 'edgeType': edge_type}}
     cmd_body = {'name': filter_name, 'json': json.dumps(cmd_json)}
-    return _create_filter_and_finish('commands/filter/create', cmd_body, hide, network, base_url)
+    return _create_filter_and_finish('commands/filter/create', cmd_body, hide, apply, network, base_url)
 
 
 @cy_log
-def create_composite_filter(filter_name, filter_list, type='ALL', hide=False, network=None, base_url=DEFAULT_BASE_URL):
+def create_composite_filter(filter_name, filter_list, type='ALL', hide=False, network=None, base_url=DEFAULT_BASE_URL, *, apply=True):
     """Combine filters to control node and edge selection based on previously created filters.
 
     Args:
@@ -237,12 +245,13 @@ def create_composite_filter(filter_name, filter_list, type='ALL', hide=False, ne
         base_url (str): Ignore unless you need to specify a custom domain,
             port or version to connect to the CyREST API. Default is http://localhost:1234
             and the latest version of the CyREST API supported by this version of py4cytoscape.
+        apply (bool): True to execute filter immediately; False to define filter but not execute it
 
     Returns:
-        dict: {'nodes': <node list>, 'edges': <edge list>} returns list of nodes and edges selected after filter executes
+        dict: {'nodes': <node list>, 'edges': <edge list>} returns list of nodes and edges selected after filter executes; None if filter wasn't applied
 
     Raises:
-        CyError: if filter list contains less than one filter or has filters that don't exist
+        CyError: if filter list contains less than one filter or has filters that don't exist, or filter couldn't be applied
         requests.exceptions.RequestException: if can't connect to Cytoscape or Cytoscape returns an error
 
     Examples:
@@ -252,6 +261,8 @@ def create_composite_filter(filter_name, filter_list, type='ALL', hide=False, ne
         {'nodes': ['YDR395W', 'YLR362W', 'YPL248C', 'YGL035C'], 'edges': [{'YPR119W (pd) YMR043W', 'YDR412W (pp) YPR119W'}]}
         >>> create_composite_filter('New Filter', ['degree filter 1x', 'degree filter 2x'], hide=True)
         {'nodes': ['YDR395W', 'YLR362W', 'YPL248C', 'YGL035C'], 'edges': None}
+        >>> create_composite_filter('New Filter', ['degree filter 1x', 'degree filter 2x'], apply=False)
+        {'nodes': ['YDR395W', 'YLR362W', 'YPL248C', 'YGL035C'], 'edges': None}
     """
     networks.set_current_network(network, base_url=base_url)
 
@@ -271,7 +282,7 @@ def create_composite_filter(filter_name, filter_list, type='ALL', hide=False, ne
 
     cmd_json = {'id': 'CompositeFilter', 'parameters': {'type': type}, 'transformers': trans_list}
     cmd_body = {'name': filter_name, 'json': json.dumps(cmd_json)}
-    return _create_filter_and_finish('commands/filter/create', cmd_body, hide, network, base_url)
+    return _create_filter_and_finish('commands/filter/create', cmd_body, hide, apply, network, base_url)
 
 
 @cy_log
@@ -298,7 +309,7 @@ def get_filter_list(base_url=DEFAULT_BASE_URL):
 
 
 @cy_log
-def export_filters(filename='filters.json', base_url=DEFAULT_BASE_URL):
+def export_filters(filename='filters.json', base_url=DEFAULT_BASE_URL, *, overwrite_file=True):
     """Saves filters to file in JSON format.
 
     Args:
@@ -306,7 +317,8 @@ def export_filters(filename='filters.json', base_url=DEFAULT_BASE_URL):
         base_url (str): Ignore unless you need to specify a custom domain,
             port or version to connect to the CyREST API. Default is http://localhost:1234
             and the latest version of the CyREST API supported by this version of py4cytoscape.
-
+        overwrite_file (bool): False allows an error to be generated if the file already exists;
+            True allows Cytoscape to overwrite it without asking
     Returns:
         list: []
 
@@ -320,14 +332,19 @@ def export_filters(filename='filters.json', base_url=DEFAULT_BASE_URL):
         []
         >>> export_filters('test') # Saves all filters in file 'test.json'
         []
+        >>> export_filters('test', overwrite_file=False) # Save filters only if test.json doesn't already exist
+        []
     """
     ext = '.json'
 
     if re.search(ext + '$', filename) is None: filename += ext
 
-    file_info = sandbox.sandbox_get_file_info(filename)
+    file_info = sandbox.sandbox_get_file_info(filename, base_url=base_url)
     if len(file_info['modifiedTime']) and file_info['isFile']:
-        narrate('This file has been overwritten.')
+        if overwrite_file:
+            narrate('This file has been overwritten.')
+        else:
+            raise CyError(f'File "{filename}" already exists ... filters not saved.')
     full_filename = file_info['filePath']
 
     res = commands.commands_get(f'filter export file="{full_filename}"', base_url=base_url)
@@ -366,13 +383,35 @@ def import_filters(filename, base_url=DEFAULT_BASE_URL):
     return res
 
 
-def _create_filter_and_finish(cmd, cmd_body, hide, network, base_url):
-    res = commands.cyrest_post(cmd, body=cmd_body, base_url=base_url)
+def _create_filter_and_finish(cmd, cmd_body, hide, apply, network, base_url):
+    AUTO_APPLY_THRESHOLD = 100000
+    if check_supported_versions(cytoscape='3.9') is None:
+        cmd_body['apply'] = apply
+        res = commands.cyrest_post(cmd, body=cmd_body, base_url=base_url)
+    else:
+        # Before Cytoscape 3.9, the filter was automatically applied when it was created unless
+        # the total of nodes and edges was 100,000 or more. So, we create the filter and then
+        # consider applying it if it wasn't automatically applied already.
+        res = commands.cyrest_post(cmd, body=cmd_body, base_url=base_url)
+        if networks.get_node_count(network=network, base_url=base_url) \
+           + networks.get_edge_count(network=network, base_url=base_url) > AUTO_APPLY_THRESHOLD:
+            if apply:
+                show_error('Warning -- Cytoscape version pre-3.9 in use ... explicitly applying filter')
+                res = commands.commands_post(
+                    f'filter apply container="filter" name="{cmd_body["name"]}" network="{network}"',
+                    base_url=base_url)
+        elif not apply:
+            raise CyError('Attempt to create but not apply filter in Cytoscape version pre-3.9 is not supported')
+
     return _check_selected(hide, network, base_url)
 
 
 def _check_selected(hide, network, base_url):
-    time.sleep(MODEL_PROPAGATION_SECS)  # Yikes! Have to wait a second for selection to settle!
+    if check_supported_versions(cytoscape='3.9'):
+        # This delay became unnecessary in Cytoscape 3.9
+        show_error('Warning -- Cytoscape version pre-3.9 in use ... settling delay inserted after filter execution')
+        time.sleep(CATCHUP_FILTER_SECS)  # Yikes! Have to wait a second for selection to settle!
+
     sel_nodes = network_selection.get_selected_nodes(network=network, base_url=base_url)
     sel_edges = network_selection.get_selected_edges(network=network, base_url=base_url)
 
