@@ -8,17 +8,17 @@ II. Specific functions for defining particular node, edge and network properties
 
 """Copyright 2020 The Cytoscape Consortium
 
-Permission is hereby granted, free of charge, to any person obtaining a copy of this software and associated 
-documentation files (the "Software"), to deal in the Software without restriction, including without limitation the 
-rights to use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies of the Software, and to permit 
+Permission is hereby granted, free of charge, to any person obtaining a copy of this software and associated
+documentation files (the "Software"), to deal in the Software without restriction, including without limitation the
+rights to use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies of the Software, and to permit
 persons to whom the Software is furnished to do so, subject to the following conditions:
 
-The above copyright notice and this permission notice shall be included in all copies or substantial portions of the 
+The above copyright notice and this permission notice shall be included in all copies or substantial portions of the
 Software.
 
-THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO 
-THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE 
-AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, 
+THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO
+THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
+AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT,
 TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
 """
 
@@ -190,7 +190,7 @@ def update_style_mapping(style_name, mapping, base_url=DEFAULT_BASE_URL):
 
     if style_name is None:
         style_name = 'default'
-        narrate(f'style_name not specified; updating "default" style.')
+        narrate(f'style_name not specified, so updating "default" style.')
 
     # check if vp exists already
     res = commands.cyrest_get(f'styles/{style_name}/mappings', base_url=base_url)
@@ -276,7 +276,7 @@ def get_style_mapping(style_name, visual_prop, base_url=DEFAULT_BASE_URL):
     """
     if style_name is None:
         style_name = 'default'
-        narrate(f'style_name not specified; accessing "default" style.')
+        narrate(f'style_name not specified, so accessing "default" style.')
 
     # check if vp exists already
     res = commands.cyrest_get(f'styles/{style_name}/mappings', base_url=base_url)
@@ -316,7 +316,7 @@ def get_style_all_mappings(style_name, base_url=DEFAULT_BASE_URL):
     """
     if style_name is None:
         style_name = 'default'
-        narrate(f'style_name not specified; accessing "default" style.')
+        narrate(f'style_name not specified, so accessing "default" style.')
 
     res = commands.cyrest_get(f'styles/{style_name}/mappings', base_url=base_url)
     return res
