@@ -9,17 +9,17 @@ II. General property functions
 
 """Copyright 2020 The Cytoscape Consortium
 
-Permission is hereby granted, free of charge, to any person obtaining a copy of this software and associated 
-documentation files (the "Software"), to deal in the Software without restriction, including without limitation the 
-rights to use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies of the Software, and to permit 
+Permission is hereby granted, free of charge, to any person obtaining a copy of this software and associated
+documentation files (the "Software"), to deal in the Software without restriction, including without limitation the
+rights to use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies of the Software, and to permit
 persons to whom the Software is furnished to do so, subject to the following conditions:
 
-The above copyright notice and this permission notice shall be included in all copies or substantial portions of the 
+The above copyright notice and this permission notice shall be included in all copies or substantial portions of the
 Software.
 
-THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO 
-THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE 
-AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, 
+THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO
+THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
+AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT,
 TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
 """
 
@@ -31,6 +31,7 @@ import warnings
 from . import commands
 from . import networks
 from . import sandbox
+from . import network_views
 
 # Internal module convenience imports
 from .exceptions import CyError
@@ -152,7 +153,7 @@ def delete_visual_style(style_name, base_url=DEFAULT_BASE_URL):
     return res
 
 @cy_log
-def export_visual_styles(filename=None, type='XML', styles=None, base_url=DEFAULT_BASE_URL):
+def export_visual_styles(filename=None, type='XML', styles=None, base_url=DEFAULT_BASE_URL, *, overwrite_file=False):
     """Save one or more visual styles to file.
 
     Args:
@@ -166,12 +167,13 @@ def export_visual_styles(filename=None, type='XML', styles=None, base_url=DEFAUL
         base_url (str): Ignore unless you need to specify a custom domain,
             port or version to connect to the CyREST API. Default is http://127.0.0.1:1234
             and the latest version of the CyREST API supported by this version of py4cytoscape.
-
+        overwrite_file (bool): False allows Cytoscape show a message box before overwriting the file if the file already
+            exists; True allows Cytoscape to overwrite it without asking
     Returns:
         dict: {'file': name of file written}
 
     Raises:
-        CyError: if the output file can't be created
+        CyError: if the output file can't be created, or if file exists and user opts to not overwrite it
         requests.exceptions.RequestException: if can't connect to Cytoscape or Cytoscape returns an error
 
     Examples:
@@ -179,6 +181,8 @@ def export_visual_styles(filename=None, type='XML', styles=None, base_url=DEFAUL
         {'file': 'C:\\Users\\CyDeveloper\\styles.xml'}
         >>> export_visual_styles('curstyle') # export the current style to curstyle.xml in the current directory
         {'file': 'C:\\Users\\CyDeveloper\\curstyle.xml'}
+        >>> export_visual_styles('curstyle', overwrite_file=True) # overwrite any existing curstyle.xml file
+        {'file': 'C:\\Users\\CyDeveloper\\curstyle.xml'}
         >>> export_visual_styles('curstyle', type='json') # export the current style in cytoscape.js format
         {'file': 'C:\\Users\\CyDeveloper\\curstyle.json'}
 
@@ -193,13 +197,15 @@ def export_visual_styles(filename=None, type='XML', styles=None, base_url=DEFAUL
     ext = '.' + type.lower() + '$'
     if re.search(ext, filename.lower()) is None: filename += '.' + type.lower()
 
-    file_info = sandbox.sandbox_get_file_info(filename)
+    file_info = sandbox.sandbox_get_file_info(filename, base_url=base_url)
     if len(file_info['modifiedTime']) and file_info['isFile']:
-        narrate('This file already exists. A Cytoscape popup will be generated to confirm overwrite.')
+        if overwrite_file:
+            sandbox.sandbox_remove_file(filename, base_url=base_url)
+        else:
+            narrate('This file already exists. A Cytoscape popup will be generated to confirm overwrite.')
     full_filename = file_info['filePath']
 
     cmd_string += f' OutputFile="{full_filename}"'
-    # TODO: Can't we create a parameter to delete the file first?
 
     res = commands.commands_post(cmd_string, base_url=base_url)
     return res
@@ -390,3 +396,31 @@ def get_visual_property_names(base_url=DEFAULT_BASE_URL):
     res = commands.cyrest_get('styles/default/defaults', base_url=base_url)
     visual_properties = [prop['visualProperty']     for prop in res['defaults']]
     return visual_properties
+
+
+@cy_log
+def get_current_style(network=None, base_url=DEFAULT_BASE_URL):
+    """Get the current visual style applied to a network.
+
+    Args:
+        network (str or SUID or None): Name or SUID of the network or view. Default is the "current" network active in Cytoscape.
+                If a network view SUID is provided, then it is validated and returned.
+        base_url (str): Ignore unless you need to specify a custom domain,
+            port or version to connect to the CyREST API. Default is http://127.0.0.1:1234
+            and the latest version of the CyREST API supported by this version of py4cytoscape.
+
+    Returns:
+        str: Name of style
+
+    Raises:
+        CyError: if style doesn't exist or network doesn't exist
+        requests.exceptions.RequestException: if can't connect to Cytoscape or Cytoscape returns an error
+
+    Examples:
+        >>> get_current_style()
+        "default"
+    """
+    net_suid = networks.get_network_suid(network, base_url=base_url)
+    view_suid = network_views.get_network_view_suid(net_suid, base_url=base_url)
+    res = commands.cyrest_get(f'networks/{net_suid}/views/{view_suid}/currentStyle', base_url=base_url)
+    return res['title']
